#!/bin/sh

set -ex

service corosync stop

crm cluster init --yes --name=autopkgtest --unicast

crm cluster geo-init --yes --clusters=autopkgtest=127.2.2.2 --tickets=ticket1
crm resource start g-booth
sleep 5

crm status

crm status | grep -q booth-ip.*Started
crm status | grep -q booth-site.*Started

: INFO all tests OK
exit 0
